!*************************************************************************
! This file is part of
!
!       HiggsBounds 2.1.1 (fotran 77 version)
!
! by Philip Bechtle, Oliver Brein, Sven Heinemyer, Georg Weiglein
!    and Karina E. Williams.
!
!  Journal References: 
!     Version 1.0.0: Comput.Phys.Commun.181:138-167,2010 (arXiv:0811.4169 [hep-ph]),
!     Version 2.0.0: arXiv:1102.1898 [hep-ph], submitted to CPC.
!  Web site: http://projects.hepforge.org/higgsbounds/
!
! 7/4/2011
!*************************************************************************

*****************************************************************************
        subroutine det_chan_n_expid_from_output_chan(NHIGGS,NHPLUS,whichexpt,
     &		output_chan,experiment_id,exp_chan)
*****************************************************************************
        implicit none
	character*5 whichexpt
	integer NHIGGS,NHPLUS,experiment_id,exp_chan,output_chan,tev_offset

#include "tables-indexing-lep_cb.h"
#include "tables-indexing-tev_cb.h"


	if(output_chan .eq. 0) then
		experiment_id = 0
	else
	if(whichexpt .eq. 'onlyT') then
		tev_offset=0
		experiment_id=2
		exp_chan=output_chan
	elseif(whichexpt .eq. 'onlyL') then
		experiment_id=1
		exp_chan=output_chan
	elseif((whichexpt .eq. 'LandT') .or. (whichexpt .eq. 'onlyP')) then
		tev_offset=nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS+nLEP_NDCHN*NHIGGS**2
		if(output_chan .le. tev_offset) then
			experiment_id=1
			exp_chan=output_chan
		elseif(output_chan .gt. tev_offset) then
			experiment_id=2
			exp_chan=output_chan-tev_offset
		endif
	elseif(whichexpt .eq. 'singH') then
		tev_offset=nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS
		if(output_chan .le. tev_offset) then
			experiment_id=1
			exp_chan=output_chan
		elseif(output_chan .gt. tev_offset) then
			experiment_id=2
			exp_chan=output_chan-tev_offset
		endif
	endif
	endif

	end



!******************************************************************
	subroutine write_table_key(file_id,NHIGGS,NHPLUS,whichexpt)
!******************************************************************
	implicit none
	character*5 whichexpt
	logical useTEV,useLEP,useSingH
        integer NHIGGS,NHPLUS,file_id
        integer output_chan,channel,number_channels

#include "tables-indexing-lep_cb.h"
#include "tables-indexing-tev_cb.h"

	call determine_topology_flags(whichexpt,
     &          useTEV,useLEP,useSingH)

	number_channels = 0

	if(useLEP) then
	  if(useSingH) then
		number_channels = nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS
	  else
		number_channels = nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS
     &				  +nLEP_NDCHN*NHIGGS**2
	  endif
	endif

	if(useTEV) then
	  number_channels = number_channels 
     &		+ nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS+nTEV_NDCHN*NHIGGS**2
	endif

	do output_chan=0,number_channels
	  call write_output_channel(file_id,NHIGGS,NHPLUS,whichexpt,
     &                                  output_chan)
	enddo

	end



!******************************************************************
	subroutine write_output_channel(file_id,NHIGGS,NHPLUS,whichexpt,
     &					output_chan)
!******************************************************************
	implicit none
	character*5 whichexpt
	character*4 prefix
        integer NHIGGS,NHPLUS,file_id,m,n,i,j,findi,findj
        integer TEV_reaction_number,TEV_analysis_number
        integer LEP_reaction_number,LEP_analysis_number
	integer output_chan,channel,experiment_id,analysis,offset

#include "tables-indexing-lep_cb.h"
#include "tables-indexing-tev_cb.h"

	if(file_id .eq. 6) then	
		prefix='    '	
	else
		prefix=' #  '
	endif

 	call det_chan_n_expid_from_output_chan(NHIGGS,NHPLUS,whichexpt,
     &          output_chan,experiment_id,channel)

! 16.1.2009
	if(output_chan .eq. 0) then
	write(file_id,90) prefix
 90	FORMAT(A4,'  0: no analysis applies')
	endif

	if(experiment_id .eq. 1) then
	  n=LEP_reaction_number(NHIGGS,NHPLUS,channel)
	  analysis=LEP_analysis_number(NHIGGS,NHPLUS,channel)
	  
	  if(channel .le. nLEP_NSneutCHN*NHIGGS) then
	    if(id_Sneut(analysis) .eq. nLEPhZ_bbZ) then
	      write(file_id,142) prefix,output_chan,n,n
 142          FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_tautauZ)  then
	      write(file_id,143) prefix,output_chan,n,n
 143          FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_anyZ)  then
	      write(file_id,1400) prefix,output_chan,n,n
 1400         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> anything (OPAL, EPJC 27(2003)311)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_gamgamZ)  then
	      write(file_id,1401) prefix,output_chan,n,n
 1401         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> gamma gamma (LEP, LHWG note 2002-02)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_jjZ)  then
	      write(file_id,1402) prefix,output_chan,n,n
 1402         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> hadrons (LEP combined limit)')
            elseif(id_Sneut(analysis) .eq. nLEPhZ_invisZ)  then
	      write(file_id,1403) prefix,output_chan,n,n
 1403         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> invisible (hep-ex/0107032)')
            elseif(id_Sneut(analysis) .eq. nDELPHIbbh_4b)  then
	      write(file_id,1404) prefix,output_chan,n
 1404         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 4 b, H CP even, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHIbba_4b)  then
	      write(file_id,1405) prefix,output_chan,n
 1405         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 4 b, H CP odd, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHIbbh_2b2tau)  then
	      write(file_id,1406) prefix,output_chan,n
 1406         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 2b 2tau, H CP even, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHIbba_2b2tau)  then
	      write(file_id,1407) prefix,output_chan,n
 1407         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 2b 2tau, H CP odd, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHItautauh_4tau)  then
	      write(file_id,1408) prefix,output_chan,n
 1408         FORMAT (A4,I3,':  e+ e- -> tau tau H(',I1,') -> 4 tau, H CP even, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHItautaua_4tau)  then
	      write(file_id,1409) prefix,output_chan,n
 1409         FORMAT (A4,I3,':  e+ e- -> tau tau H(',I1,') -> 4 tau, H CP odd, DELPHI (hep-ex/0410017)') 
            elseif(id_Sneut(analysis) .eq. nDELPHIhZ_invisZ)  then
	      write(file_id,1410) prefix,output_chan,n,n
 1410         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> invisible, DELPHI (hep-ex/0401022)')
            elseif(id_Sneut(analysis) .eq. nL3hZ_invisZ)  then
	      write(file_id,1411) prefix,output_chan,n,n
 1411         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> invisible, L3 (hep-ex/0501033)')
            elseif(id_Sneut(analysis) .eq. nOPALhZ_invisZ)  then
	      write(file_id,1412) prefix,output_chan,n,n
 1412         FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> invisible, OPAL (hep-ex/0707.0373)')
            elseif(id_Sneut(analysis) .eq. nOPALbbh_2b2tau)  then
	      write(file_id,1413) prefix,output_chan,n
 1413         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 2b 2tau, H CP even, OPAL (hep-ex/0111010)') 
            elseif(id_Sneut(analysis) .eq. nOPALbba_2b2tau)  then
	      write(file_id,1414) prefix,output_chan,n
 1414         FORMAT (A4,I3,':  e+ e- -> bb H(',I1,') -> 2b 2tau, H CP odd, OPAL (hep-ex/0111010)') 
 	    endif
	  elseif((channel .gt. nLEP_NSneutCHN*NHIGGS) 
     &		 .and. (channel .le. nLEP_NSneutCHN*NHIGGS+nLEP_NScharCHN*NHPLUS)) then
c ... charged Higgs analyses
	    offset=nLEP_NSneutCHN
            if(id_Schar(analysis-offset) .eq. nOPALhphm_2tau2nu)  then
	      write(file_id,1501) prefix,output_chan,n,n
 1501         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 2 tau 2 nu, OPAL (hep-ex/0812.0267)') 
            elseif(id_Schar(analysis-offset) .eq. nOPALhphm_2jtaunu)  then
	      write(file_id,1502) prefix,output_chan,n,n
 1502         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 2 jets tau nu, OPAL (hep-ex/0812.0267)') 
            elseif(id_Schar(analysis-offset) .eq. nOPALhphm_4j)  then
	      write(file_id,1503) prefix,output_chan,n,n
 1503         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 4 jets, OPAL (hep-ex/0812.0267)') 
            elseif(id_Schar(analysis-offset) .eq. nLEPhphm_4j)  then
	      write(file_id,1504) prefix,output_chan,n,n
 1504         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 4 jets, LEP (hep-ex/0107031)') 
            elseif(id_Schar(analysis-offset) .eq. nDELPHIhphm_4j)  then
	      write(file_id,1505) prefix,output_chan,n,n
 1505         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 4 jets, DELPHI (hep-ex/0404012)') 
            elseif(id_Schar(analysis-offset) .eq. nDELPHIhphm_2tau2nu)  then
	      write(file_id,1506) prefix,output_chan,n,n
 1506         FORMAT (A4,I3,':  e+ e- -> H+(',I1,') H-(',I1,') -> 2 tau 2 nu, DELPHI (hep-ex/0404012)') 
	    endif
	  else
c ... double Higgs analyses
	    offset=nLEP_NSneutCHN+nLEP_NScharCHN 
	    i=findi(NHIGGS,n)
	    j=findj(NHIGGS,n)
	      if(id_Dneut(analysis-offset) .eq. nLEPh2Z_h1h1Z_4bZ) then
		write(file_id,150) prefix,output_chan,j,j,i,i,i
 150 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2Z_h1h1Z_4tauZ) then
		write(file_id,160) prefix,output_chan,j,j,i,i,i
 160 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_4b) then
		write(file_id,180) prefix,output_chan,j,i,j,i
 180 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'),  H(',I1,'), H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_4tau) then 
		write(file_id,190) prefix,output_chan,j,i,j,i
 190 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'),  H(',I1,'), H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_h1h1h1_6b) then 
		write(file_id,200) prefix,output_chan,j,i,j,i,i,i
 200 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'), H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_h1h1h1_6tau) then
		write(file_id,210) prefix,output_chan,j,i,j,i,i,i
 210 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'), H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2Z_h1h1Z_2b2tau) then
		write(file_id,220) prefix,output_chan,j,j,i,i,i
 220 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') Z, H(',I1,') -> H(',I1,') H(',I1,'), H(',I1,') -> b b, tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_2b2tau) then
		write(file_id,230) prefix,output_chan,j,i,j,i
 230 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'), H(',I1,') -> b b, H(',I1,') -> tau tau (LEP, EPJC 46(2006)547)')
              elseif(id_Dneut(analysis-offset) .eq. nLEPh2h1_2tau2b) then
		write(file_id,240) prefix,output_chan,j,i,j,i
 240 		FORMAT (A4,I3,':  e+ e- -> H(',I1,') H(',I1,'), H(',I1,') -> tau tau, H(',I1,') -> b b (LEP, EPJC 46(2006)547)')
	      endif
	  endif
	endif

	if(experiment_id .eq. 2) then

	  n=TEV_reaction_number(NHIGGS,NHPLUS,channel)
	  analysis=TEV_analysis_number(NHIGGS,NHPLUS,channel)

	  if(channel .le. nTEV_NSneutCHN*NHIGGS) then

	   if(tev_id_Sneut(analysis) .eq. nCDF1009_3047) write(file_id,1001) prefix,output_chan,n
	   if(tev_id_Sneut(analysis) .eq. nCDF10235) write(file_id,1002) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10212) write(file_id,1003) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06089) write(file_id,1004) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06087) write(file_id,1005) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF8961_D05536) write(file_id,1009) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10105) write(file_id,1010) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06092) write(file_id,1011) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10239) write(file_id,1013) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05726) write(file_id,1014) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01011_1931) write(file_id,1015) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00805_2491) write(file_id,1017) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF0906_1014) write(file_id,1018) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05873) write(file_id,1019) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF7307v3) write(file_id,1020) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05858) write(file_id,1022) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00803_1514) write(file_id,1023) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10133) write(file_id,1024) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF9290_D05645) write(file_id,1025) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05757) write(file_id,1026) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF0809_3930) write(file_id,1027) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF9465_D05754) write(file_id,1028) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10102) write(file_id,1029) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05871) write(file_id,1030) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01012_0874) write(file_id,1031) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF0906_5613) write(file_id,1032) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00912_0968) write(file_id,1033) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05740) write(file_id,1034) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00912_5285) write(file_id,1035) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF0911_3935) write(file_id,1036) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00901_1887) write(file_id,1037) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00712_0598) write(file_id,1039) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10099_D06063) write(file_id,1040) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05985) write(file_id,1042) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF9999) write(file_id,1043) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05739) write(file_id,1044) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00806_0611) write(file_id,1045) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01001_4481) write(file_id,1048) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD00903_4800) write(file_id,1049) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD05845) write(file_id,1050) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06008) write(file_id,1051) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF9998_D05983) write(file_id,1052) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10065) write(file_id,1053) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10010) write(file_id,1054) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF1001_4468) write(file_id,1057) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF_D0_1001_4162) write(file_id,1058) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF_D0_1005_3216) write(file_id,1059) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06082) write(file_id,1060) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06091) write(file_id,1061) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06083abslim) write(file_id,1062) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD06083) write(file_id,1063) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nCDF10241_D06096) write(file_id,1064) prefix,output_chan,n
           if(tev_id_Sneut(analysis) .eq. nD01008_3564) write(file_id,1065) prefix,output_chan,n
 
	  elseif((channel .gt. nTEV_NSneutCHN*NHIGGS) 
     &		 .and. (channel .le. nTEV_NSneutCHN*NHIGGS+nTEV_NScharCHN*NHPLUS)) then
c ... charged Higgs analyses
	    offset=nTEV_NSneutCHN
          
           if(tev_id_Schar(analysis-offset) .eq. nD00908_1811cs) write(file_id,1046) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nD00908_1811taunu) write(file_id,1047) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nCDF0907_1269low) write(file_id,1055) prefix,output_chan,n,n
           if(tev_id_Schar(analysis-offset) .eq. nCDF0907_1269hi) write(file_id,1056) prefix,output_chan,n,n

          else
c ... double neutral Higgs analyses        
!>> currently not needed. if needed: edit !
!	   offset=nTEV_NSneutCHN+nTEV_NScharCHN
!	  i=findi(NHIGGS,n)
!	  j=findj(NHIGGS,n)
! ......
!<< currently not needed. if needed edit !	   
	  endif
	  
	endif

 1001	FORMAT (A4,I3,': p p-bar -> Z H(',I1,') -> l l b b-bar, CDF with 4.1 fb^-1 (hep-ex/1009.3047)')
 1002	FORMAT (A4,I3,': p p-bar -> Z H(',I1,') -> l l b b-bar, CDF with 5.7 fb^-1 (CDF note 10235)')
 1003   FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar + miss. E_T (V=W,Z), CDF with 5.7 fb^-1 SM combined (CDF note 10212)')
 1004	FORMAT (A4,I3,': p p-bar -> Z H(',I1,') -> l l b b-bar, D0 with 6.2 fb^-1 (D0 note 6089)')
 1005	FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar + miss. E_T (V=W,Z), D0 with 6.4 fb^-1 SM combined (D0 note 6087)')
 1009	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM combined with 2-4.8 fb ^-1 (hep-ex/0712.2383)')
 1010	FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> 3 b jets, CDF with 2.5 fb^-1 (CDF note 10105)')
 1011   FORMAT (A4,I3,': p p-bar -> W H(',I1,'), H -> b b-bar, D0 with 5.3 fb^-1 (D0 note 6092)')
 1013   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> l nu b b-bar, CDF with 5.7 fb^-1 (CDF note 10239)')
 1014   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> 3 b jets, D0 with 2.6 fb^-1 (D0 note 5726)')
 1015   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> 3 b jets, D0 (hep-ex/1011.1931)')
 1017   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> tau tau, D0 with 1 fb^-1 absolute limits (D0 hep-ex/0805.2491)')
 1018   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> tau tau, CDF with 1.8 fb^-1 absolute limits (CDF hep-ex/0906.1014)')
 1019   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> 3 Ws, D0 with 3.6 fb^-1 (D0 note 5873)') 
 1020   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> 3 Ws, CDF with 2.7 fb^-1 (CDF note 7307 version 3)')
 1022   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, D0 with 4.2 fb^-1 (D0 note 5858)')
 1023   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, D0 with 1.1 fb^-1 absolute limits (D0 hep-ex/0803.1514)')
 1024	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> tau tau, CDF with 2.3 fb^-1 SM combined (CDF note 10133)')
 1025   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM combined with 1-2.4 fb^-1 (hep-ex/0804.3423)')
 1026	FORMAT (A4,I3,': p p-bar -> H(',I1,') -> W W -> l l, D0 with 3.0 fb^-1 (D0 note 5757)')
 1027   FORMAT (A4,I3,': p p-bar -> single H(',I1,') -> W W, CDF with 3.0 fb^-1 (hep-ex/0809.3930)')
 1028	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM combined with 3 fb^-1 (hep-ex/0808.0534)')
 1029   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, CDF with 5.3 fb^-1 SM combined (CDF note 10102)')
 1030   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, D0 with 4.2 fb^-1 SM combined (D0 note 5871)')
 1031   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> l nu b b-bar, D0 with 5.3k fb^-1 (hep-ex/1012.0874)')
 1032   FORMAT (A4,I3,': p p-bar -> W H(',I1,') -> l nu b b-bar, CDF with 2.7 fb^-1 (hep-ex/0906.5613)')
 1033   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 2.7 fb^-1 (hep-ex/0912.0968)')
 1034	FORMAT (A4,I3,': p p-bar -> H(',I1,') -> tau tau, D0 with 2.2 fb^-1 absolute limits (D0 note 5740)')
 1035	FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar + miss. E_T (V=W,Z), D0 with 5.2 fb^-1 (hep-ex/0912.5285)')
 1036	FORMAT (A4,I3,': p p-bar -> V H(',I1,') -> b b-bar + miss. E_T (V=W,Z), CDF with 2.1 fb^-1 (hep-ex/0911.3935)')
 1037   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, D0 with 2.7 fb^-1 (D0 hep-ex/0901.1887)')
 1039	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, SM combined with 0.44 fb^-1 (D0 hep-ex/0712.0598)')
 1040	FORMAT (A4,I3,': p p-bar -> H(',I1,') -> tau tau, CDF & D0 combined with up to 2.2 fb^-1 absolute limits (hep-ex/1003.3363)')
 1042   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 2.7 fb^-1 (D0 note 5985)')
 1043   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, SM combined with 2.0-4.8 fb^-1 (CDF note 9999)')
 1044   FORMAT (A4,I3,': p p-bar -> ttH(',I1,') -> ttbb, D0 with 2.1 fb^-1 (D0 note 5739)')
 1045   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> Z gamma, D0 with 1.0 fb^-1 absolute limits (D0 hep-ex/0806.0611)')
 1046   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> cs, D0 with 1.0 fb^-1 BR(t->H+b) limits (D0 hep-ex/0908.1811)')
 1047   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> tau nu, D0 with 1.0 fb^-1 BR(t->H+b) limits (D0 hep-ex/0908.1811)')
 1048   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, D0 with 5.4 fb^-1 (D0 hep-ex/1001.4481)')
 1049	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> tau tau, D0 with 1.0 fb^-1 SM combined (hep-ex/0903.4800)')
 1050	FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> tau tau, D0 with 4.9 fb^-1 SM combined (D0 note 5845)')
 1051   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, SM combined, D0 with 2.1-5.4 fb^-1 (D0 note 6008)')
 1052   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM SM combined with 2.1-5.4 fb^-1 (hep-ex/0911.3930)')
 1053   FORMAT (A4,I3,': p p-bar -> H(',I1,') -> gamma gamma, CDF with 5.4 fb^-1 SM combined (CDF note 10065)')
 1054   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> b b + X, CDF with 4 fb^-1 SM combined (CDF note 10010)')
 1055   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> cs, CDF with 2.2 fb^-1 BR(t->H+b) limits, low mass part (CDF hep-ex/0907.1269)')
 1056   FORMAT (A4,I3,': p p-bar -> t t, t -> H+(',I1,') b, H+(',I1,') -> cs, CDF with 2.2 fb^-1 BR(t->H+b) limits, high mass part (CDF hep-ex/0907.1269)')
 1057   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, CDF with 4.8 fb^-1 SM combined (hep-ex/1001.4468)')
 1058   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, CDF & D0 with 4.8-5.4 fb^-1 SM combined (hep-ex/1001.4162)')
 1059   FORMAT (A4,I3,': p p-bar -> single H(',I1,') -> W W, CDF & D0 with 4.8/5.4 fb^-1 (hep-ex/1005.3216)')
 1060   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X -> W W + X, D0 with 6.7 fb^-1 SM combined (D0 note 6082)')
 1061   FORMAT (A4,I3,': p p-bar -> VH(',I1,') -> VVV -> same sign di-lepton(e,mu) (V=W,Z), D0 with 6.4 fb^-1 SM combined (D0 note 6091)')
 1062   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 4.3 fb^-1 absolute limits (D0 note 6083)')
 1063   FORMAT (A4,I3,': p p-bar -> b H(',I1,') -> b tau tau, D0 with 4.3 fb^-1 (D0 note 6083)')
 1064   FORMAT (A4,I3,': p p-bar -> H(',I1,') + X, CDF & D0 SM SM combined with up to 5.9/6.7 fb^-1 (hep-ex/1007.4587)')
 1065	FORMAT (A4,I3,': p p-bar -> Z H(',I1,') -> l l b b-bar, D0 with 4.2 fb^-1 (D0 hep-ex/1008.3564)')

	end
